@@ -19,14 +19,14 @@
 
 from __future__ import annotations
 
-import warnings
-from typing import TYPE_CHECKING, Any, Iterable, overload
+from collections.abc import Iterable
+from typing import TYPE_CHECKING, Any, overload
 from urllib.parse import quote_plus, urlunsplit
 
 import pymongo
 from pymongo import MongoClient, ReplaceOne
 
-from airflow.exceptions import AirflowConfigException, AirflowProviderDeprecationWarning
+from airflow.exceptions import AirflowConfigException
 from airflow.hooks.base import BaseHook
 
 if TYPE_CHECKING:
@@ -117,15 +117,6 @@ class MongoHook(BaseHook):
 
     def __init__(self, mongo_conn_id: str = default_conn_name, *args, **kwargs) -> None:
         super().__init__()
-        if conn_id := kwargs.pop("conn_id", None):
-            warnings.warn(
-                "Parameter `conn_id` is deprecated and will be removed in a future releases. "
-                "Please use `mongo_conn_id` instead.",
-                AirflowProviderDeprecationWarning,
-                stacklevel=2,
-            )
-            mongo_conn_id = conn_id
-
         self.mongo_conn_id = mongo_conn_id
 
         conn = self.get_connection(self.mongo_conn_id)
